==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_pl.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("To przecież wikińska łódź!")


dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Jasne, to drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Musiała szybko zatonąć, wioślarze nadal są na swoich stanowiskach.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Może celowo ją zatopili? Wojownicy zawsze towarzyszyli swojemu przywódcy do Walhalli.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Okropność... Siedzą tu jak żywi...")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("Co jest z muzyką?!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Przestali grać!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("Znów muzykę wyłączyli!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("No nie!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Znowu?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("No nie, znowu?")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Co się dzieje?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Znowu?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("No nie!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Gdzie ta cholerna muzyka?!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Co oni tam psują na górze?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Jak tak można?!")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Spoko, chłopaki. Olaf idzie w solo!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Nieważne, chłopcy. Sami sobie pośpiewamy!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Nic nie szkodzi. Pośpiewamy sobie sami, jak za starych, dobrych czasów!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_pl.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("To przecież wikińska łódź!")


dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Jasne, to drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Musiała szybko zatonąć, wioślarze nadal są na swoich stanowiskach.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Może celowo ją zatopili? Wojownicy zawsze towarzyszyli swojemu przywódcy do Walhalli.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Okropność... Siedzą tu jak żywi...")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("Co jest z muzyką?!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Przestali grać!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("Znów muzykę wyłączyli!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("No nie!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Znowu?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("No nie, znowu?")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Co się dzieje?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Znowu?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("No nie!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Gdzie ta cholerna muzyka?!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Co oni tam psują na górze?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Jak tak można?!")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Spoko, chłopaki. Olaf idzie w solo!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Nieważne, chłopcy. Sami sobie pośpiewamy!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Nic nie szkodzi. Pośpiewamy sobie sami, jak za starych, dobrych czasów!")
